@@ -4,7 +4,6 @@
 
 #include <gnome.h>
 
-
 #include "boot-image.h"
 
 typedef struct {
@@ -21,25 +20,38 @@ typedef struct {
 	GtkWidget *image_frame;
 	GtkWidget *image_widget;
 	GtkEntry  *image_entry;
-	GtkEntry  *root;
+	GtkCombo  *root;
+	GtkWidget *initrd_label;
+	GtkWidget *initrd_widget;
+	GtkEntry  *initrd_entry;
 	GtkEntry  *append;
 	GtkButton *append_browse;
 
+	/* Security Frame */
+	GtkCheckButton *use_password;
+	GtkLabel *pass_label;
+	GtkLabel *confirm_label;
+	GtkEntry *password;
+	GtkEntry *password_confirm;
+	
 	/* Other frame */
 	GtkWidget *other_frame;
 	GtkCombo  *device;
 	
 } BootSettingsGui;
 
+typedef struct _BootImageEditor
+{
+	GtkDialog *dialog;
+
+	BootSettingsGui *gui;
+} BootImageEditor;
+
 BootSettingsGui *boot_settings_gui_new      (BootImage *image, GtkWidget *parent);
 void             boot_settings_gui_setup    (BootSettingsGui *gui, GtkWidget *top);
 gboolean         boot_settings_gui_save     (BootSettingsGui *gui, gboolean check);
 void             boot_settings_gui_error    (GtkWindow *parent, gchar *error);
 void             boot_settings_gui_destroy  (BootSettingsGui *gui);
-
-/* Callbacks */ 
-
-void             on_boot_add_clicked        (GtkButton *button, gpointer data);
-void             on_boot_settings_clicked   (GtkButton *button, gpointer data);
+GList            *settings_type_list        (void);
 
 #endif /* BOOT_SETTINGS_H */
