@@ -30,6 +30,7 @@
 #include <gnome.h>
 
 #include "gst.h"
+#include "gst-hig-dialog.h"
 
 #include "callbacks.h"
 #include "transfer.h"
@@ -96,17 +97,13 @@ void
 on_network_notebook_switch_page (GtkWidget *notebook, GtkNotebookPage *page,
 				 gint page_num, gpointer user_data)
 {
-	GtkWidget *w;
-	gchar *entry[] = { "hostname", "connection_list_sw", "domain", "statichost_list" };
 	static guint timeout_id = 0;
 
-	if (gst_tool_get_access (tool) && entry[page_num]) {
-		w = gst_dialog_get_widget (tool->main_dialog, entry[page_num]);
-		if (w)
-			gtk_widget_grab_focus (w);
-	}
+	/* if the tool is running remotely, we don't want this function to be run */
+	if (tool->remote_config)
+		return;
 
-	if (page_num == 1) {
+	if (page_num == 0) {
 		timeout_id = g_timeout_add (1000, (GSourceFunc) connection_poll_stat, tool);
 	} else {
 		if (timeout_id) {
@@ -348,6 +345,7 @@ on_connection_add_clicked (GtkWidget *w, gpointer null)
 	GnomeDruid *druid = GNOME_DRUID (gst_dialog_get_widget (tool->main_dialog, "network_connection_druid"));
 
 	network_druid_new (druid, druid_window, tool, GST_CONNECTION_UNKNOWN);
+	gtk_window_set_transient_for (GTK_WINDOW (druid_window), GTK_WINDOW (tool->main_dialog));
 	gtk_widget_show_all (druid_window);
 }
 
@@ -357,25 +355,24 @@ on_connection_delete_clicked (GtkWidget *w, gpointer null)
 	GtkWidget *d;
 	GstConnection *cxn;
 	gint res;
-	gchar *txt;
 
 	cxn = connection_list_get_active ();
 
-	if (cxn->name && *cxn->name)
-		txt = g_strdup_printf (_("Remove connection %s: \"%s\"?"), cxn->dev, cxn->name);
-	else
-		txt = g_strdup_printf (_("Remove connection %s?"), cxn->dev);
+	d = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+				GTK_DIALOG_MODAL,
+				GST_HIG_MESSAGE_QUESTION,
+				NULL,
+				_("This will disable any network connection with this interface as soon as you hit \"apply\"."),
+				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
+				NULL);
+	gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (d),
+					 _("Are you sure you want to delete connection \"%s\"?"), cxn->dev);
 
-	d = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-				    GTK_DIALOG_MODAL,
-				    GTK_MESSAGE_QUESTION,
-				    GTK_BUTTONS_YES_NO,
-				    txt);
-	g_free (txt);
 	res = gtk_dialog_run (GTK_DIALOG (d));
 	gtk_widget_destroy (d);
 	
-	if (res == GTK_RESPONSE_YES) {
+	if (res == GTK_RESPONSE_ACCEPT) {
 		connection_default_gw_remove (cxn->dev);
 		connection_list_remove (cxn);
 		connection_free (cxn);	
@@ -456,14 +453,15 @@ on_samba_use_toggled (GtkWidget *w, gpointer null)
 		GtkWidget *dialog;
 		
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
-		dialog = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_INFO,
-						 GTK_BUTTONS_OK,
-						 _("You don't have SMB support installed. Please install "
-						   "SMB support in the system to enable windows networking."));
 
-		gtk_window_set_title (GTK_WINDOW (dialog), _("SMB support missing."));
+		dialog = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+					     GTK_DIALOG_MODAL,
+					     GST_HIG_MESSAGE_INFO,
+					     _("SMB Support is not running"),
+					     _("You don't have SMB support installed. Please install "
+					       "SMB support in the system to enable windows networking."),
+					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					     NULL);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		return;
@@ -475,7 +473,7 @@ on_samba_use_toggled (GtkWidget *w, gpointer null)
 	gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "workgroup"), active);
 	gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "wins_use"), active);
 
-	if ((active) && (gtk_toggle_button_get_active (gst_dialog_get_widget (tool->main_dialog, "wins_use"))))
+	if ((active) && (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, "wins_use")))))
 		gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "winsserver"), active);
 	else
 		gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "winsserver"), FALSE);
@@ -503,7 +501,7 @@ on_wins_use_toggled (GtkWidget *w, gpointer null)
 gboolean
 callbacks_check_hostname_hook (GstDialog *dialog, gpointer data)
 {
-	gchar *hostname_old;
+	gchar *hostname_old = NULL;
 	const gchar *hostname_new;
 	xmlNode *root, *node;
 	GtkWidget *entry;
@@ -517,31 +515,31 @@ callbacks_check_hostname_hook (GstDialog *dialog, gpointer data)
 	entry = gst_dialog_get_widget (dialog, "hostname");
 	hostname_new = gtk_entry_get_text (GTK_ENTRY (entry));
 
-	if (strcmp (hostname_new, hostname_old))
+	if (hostname_old && hostname_new && strcmp (hostname_new, hostname_old))
 	{
-		gchar *text = _("The host name has changed. This will prevent you "
-				"from launching new applications, and so you will "
-				"have to log in again. Continue anyway?");
 		GtkWidget *message;
 
-		message = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-						  GTK_DIALOG_MODAL,
-						  GTK_MESSAGE_WARNING,
-						  GTK_BUTTONS_OK_CANCEL,
-						  text);
+		message = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+					      GTK_DIALOG_MODAL,
+					      GST_HIG_MESSAGE_WARNING,
+					      _("Host name has changed"),
+					      _("This will prevent you "
+						"from launching new applications, and so you will "
+						"have to log in again. Continue anyway?"),
+					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      _("Change _Host name"), GTK_RESPONSE_ACCEPT,
+					      NULL);
 
 		res = gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 
 		switch (res) {
-		case GTK_RESPONSE_OK:
+		case GTK_RESPONSE_ACCEPT:
 			g_free (hostname_old);
 			return TRUE;
 		case GTK_RESPONSE_CANCEL:
-			gtk_entry_set_text (GTK_ENTRY (entry), hostname_old);
-			return FALSE;
 		default:
-			g_free (hostname_old);
+			gtk_entry_set_text (GTK_ENTRY (entry), hostname_old);
 			return FALSE;
 		}
 	}
@@ -567,17 +565,17 @@ callbacks_check_dialer (GtkWindow *window, GstTool *tool)
 	
 	if (!has_dialer)
 	{
-		gchar *text = _("wvdial could not be found on your system. "
-				"You need to install wvdial, or the PPP (modem) "
-				"connections will not activate.");
 		GtkWidget *message;
 
-		message = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-						  GTK_DIALOG_MODAL,
-						  GTK_MESSAGE_WARNING,
-						  GTK_BUTTONS_OK,
-						  text);
-
+		message = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+					      GTK_DIALOG_MODAL,
+					      GST_HIG_MESSAGE_WARNING,
+					      _("Wvdial missing"),
+					      _("wvdial could not be found on your system. "
+						"You need to install wvdial, or the PPP (modem) "
+						"connections will not activate."),
+					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					      NULL);
 		gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 	}
@@ -592,24 +590,24 @@ callbacks_check_dialer_hook (GstDialog *dialog, gpointer data)
 	tool = GST_TOOL (data);
 	
 	has_dialer = connection_list_has_dialer (tool);
-	if (!has_dialer)
-	{
-		gchar *text = _("wvdial could not be found on your system. "
-				"You need to install wvdial, or the PPP (modem) "
-				"connections will not activate. Continue anyway?");
-		gint res;
+	if (!has_dialer) {
 		GtkWidget *message;
+		gint res;
 
-		message = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-						  GTK_DIALOG_MODAL,
-						  GTK_MESSAGE_WARNING,
-						  GTK_BUTTONS_OK_CANCEL,
-						  text);
-
+		message = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+					      GTK_DIALOG_MODAL,
+					      GST_HIG_MESSAGE_WARNING,
+					      _("Wvdial not found"),
+					      _("wvdial could not be found on your system. "
+						"You need to install wvdial, or the PPP (modem) "
+						"connections will not activate. Continue anyway?"),
+					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      _("_Continue"), GTK_RESPONSE_ACCEPT,
+					      NULL);
 		res = gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 
-		if (res == GTK_RESPONSE_OK)
+		if (res == GTK_RESPONSE_ACCEPT)
 			return TRUE;
 		else
 			return FALSE;
@@ -619,36 +617,32 @@ callbacks_check_dialer_hook (GstDialog *dialog, gpointer data)
 }
 
 static gboolean
-callbacks_disabled_gatewaydev_warn (GstTool *tool, GstConnection *cxn, gboolean *ignore_enabled)
+callbacks_disabled_gatewaydev_warn (GstTool *tool, GstConnection *cxn)
 {
-	gchar *text = _("The default gateway device is not activated. This "
-			"will prevent you from connecting to the Internet. "
-			"Continue anyway?");
-	gint res;
 	GtkWidget *message;
+	gint res;
 
-	message = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-					  GTK_DIALOG_MODAL,
-					  GTK_MESSAGE_WARNING,
-					  GTK_BUTTONS_OK_CANCEL,
-					  text);
-
+	message = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+				      GTK_DIALOG_MODAL,
+				      GST_HIG_MESSAGE_WARNING,
+				      _("The default gateway device is not activated"),
+				      _("This will prevent you from connecting to the Internet. "
+					"Continue anyway?"),
+				      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				      _("_Continue"), GTK_RESPONSE_ACCEPT,
+				      NULL);
 	res = gtk_dialog_run (GTK_DIALOG (message));
 	gtk_widget_destroy (message);
 	
 	switch (res) {
-	case GTK_RESPONSE_OK:
+	case GTK_RESPONSE_ACCEPT:
 		connection_default_gw_fix (cxn, GST_CONNECTION_ERROR_ENABLED);
 		return TRUE;
 	case GTK_RESPONSE_CANCEL:
-		*ignore_enabled = TRUE;
-		return TRUE;
 	default:
 		return FALSE;
 		break;
 	}
-
-	return TRUE;
 }
 
 static gboolean
@@ -666,7 +660,7 @@ callbacks_check_manual_gatewaydev (GstTool *tool)
 	{
 		switch (error) {
 		case GST_CONNECTION_ERROR_ENABLED:
-			if (callbacks_disabled_gatewaydev_warn (tool, cxn, &ignore_enabled))
+			if (callbacks_disabled_gatewaydev_warn (tool, cxn))
 				continue;
 			else
 				return FALSE;
@@ -676,16 +670,15 @@ callbacks_check_manual_gatewaydev (GstTool *tool)
 		case GST_CONNECTION_ERROR_STATIC:
 		{
 			GtkWidget *dialog;
-			gchar *txt = _("The default gateway device is missing gateway "
-				       "information. Please provide this information to "
-				       "proceed, or choose another default gateway device.");
-
-			dialog = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-							 GTK_DIALOG_MODAL,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_OK,
-							 txt);
 
+			dialog = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+						     GTK_DIALOG_MODAL,
+						     GST_HIG_MESSAGE_ERROR,
+						     _("The default gateway device is missing gateway information"),
+						     _("Please provide this information to "
+						       "proceed, or choose another default gateway device."),
+						     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+						     NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 			return FALSE;
@@ -722,18 +715,17 @@ gboolean
 callbacks_tool_not_found_hook (GstTool *tool, GstReportLine *rline, gpointer data)
 {
 	if (! strcmp (rline->argv[0], "redhat-config-network-cmd")) {
-		gchar *text = _("The program redhat-config-network-cmd could not "
-				"be found. This could render missing connections "
-				"under the connections tab. Please install the "
-				"redhat-config-network rpm package to avoid this.");
 		GtkWidget *message;
 
-		message = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-						  GTK_DIALOG_MODAL,
-						  GTK_MESSAGE_WARNING,
-						  GTK_BUTTONS_OK,
-						  text);
-
+		message = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+					      GTK_DIALOG_MODAL,
+					      GST_HIG_MESSAGE_WARNING,
+					      _("The program redhat-config-network-cmd could not be found"),
+					      _("This could render missing connections "
+						"under the connections tab. Please install the "
+						"redhat-config-network rpm package to avoid this."),
+					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					      NULL);
 		gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 	}
@@ -751,34 +743,44 @@ on_connection_toggled (GtkWidget *w, gchar *path_str, gpointer data)
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
 	GtkTreeIter iter;
 	GstConnection *cxn;
-	gchar *txt;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
+	gchar *button_text    = NULL;
 	GtkWidget *dialog;
 
 	gtk_tree_model_get_iter (model, &iter, path);
 	cxn = connection_list_get_by_path (path);
 
 	if (!cxn->enabled) {
-		if (cxn->type != GST_CONNECTION_LO) {
-			txt = g_strdup_printf (_("Do you want to enable interface %s?"), cxn->dev);
-			dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, txt);
-			if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
-				on_connection_activate_clicked (GTK_WIDGET (treeview), path, NULL);
-
-			gtk_widget_destroy (dialog);
-			g_free (txt);
-		}
+		primary_text   = g_strdup_printf (_("Do you want to enable interface \"%s\"?"), cxn->dev);
+		secondary_text = g_strdup (_("This will enable network access through this interface"));
+		button_text    = g_strdup (_("_Enable"));
 	} else {
-		if (cxn->type != GST_CONNECTION_LO) {
-			txt = g_strdup_printf (_("Do you want to disable interface %s?"), cxn->dev);
-			dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, txt);
-			if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
-				on_connection_deactivate_clicked (GTK_WIDGET (treeview), path,  NULL);
-
-			gtk_widget_destroy (dialog);
-			g_free (txt);
-		}
+		primary_text   = g_strdup_printf (_("Do you want to disable interface \"%s\"?"), cxn->dev);
+		secondary_text = g_strdup (_("This will disable network access through this interface"));
+		button_text    = g_strdup (_("_Disable"));
 	}
-	
+
+	dialog = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+				     GTK_DIALOG_MODAL,
+				     GST_HIG_MESSAGE_QUESTION,
+				     primary_text,
+				     secondary_text,
+				     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				     button_text, GTK_RESPONSE_ACCEPT,
+				     NULL);
+
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		if (!cxn->enabled)
+			on_connection_activate_clicked (GTK_WIDGET (treeview), path, NULL);
+		else
+			on_connection_deactivate_clicked (GTK_WIDGET (treeview), path,  NULL);
+	}
+
+	gtk_widget_destroy (dialog);
+	g_free (primary_text);
+	g_free (secondary_text);
+	g_free (button_text);
 	gtk_tree_path_free (path);
 }
 
@@ -790,10 +792,15 @@ on_connection_ok_clicked (GtkWidget *w, gpointer data)
 	gboolean standalone = (g_object_get_data (G_OBJECT (window), "standalone") != NULL);
 	gboolean add_to_list = !standalone;
 
-	if ((cxn->modified) && (connection_config_save (cxn, FALSE))) {
+	if ((cxn->modified) && (connection_config_save (cxn, window, FALSE))) {
 		cxn->creating = FALSE;
 		gst_dialog_modify (tool->main_dialog);
 
+		if (cxn->gateway && *cxn->gateway)
+			connection_default_gw_add (cxn);
+		else
+			connection_default_gw_remove (cxn->dev);
+
 		if (standalone) {
 			gtk_widget_set_sensitive (window, FALSE);
 			connection_save_to_node (cxn, gst_xml_doc_get_root (tool->config));
@@ -855,8 +862,13 @@ on_ppp_autodetect_modem_clicked (GtkWidget *widget, gpointer data)
 	dev = connection_autodetect_modem ();
 
 	if ((!dev) || (strcmp (dev, "") == 0)) {
-		w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE,
-					    _("Could not autodetect modem device, check that this is not busy and that it's correctly attached"));
+		w = gst_hig_dialog_new (GTK_WINDOW (dialog),
+					GTK_DIALOG_MODAL,
+					GST_HIG_MESSAGE_WARNING,
+					_("Could not autodetect modem device"),
+					_("Check that it's not busy and that it's correctly attached"),
+					GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					NULL);
 		gtk_dialog_run (GTK_DIALOG (w));
 		gtk_widget_destroy (w);
 	} else {
@@ -1241,13 +1253,13 @@ on_network_druid_page_prepare (GnomeDruidPage *druid_page, GnomeDruid *druid, gp
 		"network_connection_plip_local_ip",
 		"network_connection_ppp_phone",
 		"network_connection_ppp_login",
-		"network_connection_name",
+		"network_connection_activate",
 		NULL
 	};
 
 	if (druid_data == NULL)
 		return;
-	
+
 	g_signal_stop_emission_by_name (druid_page, "prepare");
 	network_druid_check_page (druid, druid_data->current_page);
 
@@ -1284,7 +1296,10 @@ on_network_druid_finish (GnomeDruidPage *druid_page, GnomeDruid *druid, gpointer
 		connection_add_to_list (cxn);
 		connection_list_select_connection (cxn);
 
-		gst_dialog_modify (tool->main_dialog);
+		if (cxn->enabled)
+			connection_apply_and_activate (tool, cxn);
+		else
+			gst_dialog_modify (tool->main_dialog);
 
 		network_druid_clear (druid, FALSE);
 		gtk_widget_hide (window);
@@ -1292,7 +1307,7 @@ on_network_druid_finish (GnomeDruidPage *druid_page, GnomeDruid *druid, gpointer
 		connection_save_to_node (cxn, root);
 		gst_dialog_modify (tool->main_dialog);
 
-		gtk_signal_emit_by_name (GTK_OBJECT (tool->main_dialog), "apply", tool);
+		connection_apply_and_activate (tool, cxn);
 		gtk_main_quit ();
 	}
 }
@@ -1406,7 +1421,7 @@ on_network_profile_delete_clicked_foreach (GtkTreeModel *model, GtkTreePath *pat
 	
 	gtk_tree_model_get (model, iter, PROFILES_TABLE_COL_POINTER, &node, -1);
 
-	if (profile_delete (node) == TRUE)
+	if (profile_delete (node, tool) == TRUE)
 		* (gboolean *) data = TRUE;
 }
 
@@ -1452,3 +1467,61 @@ on_network_profile_option_selected (GtkWidget *widget, gpointer data)
 	
 	transfer_profile_to_gui (tool, NULL);
 }
+
+void
+on_drag_data_get (GtkTreeView *treeview, GdkDragContext *context, GtkSelectionData *data, guint info, guint time, gpointer user_data)
+{
+	GtkTreeModel *model = gtk_tree_view_get_model (treeview);
+	GtkTreePath *path;
+	GtkTreeIter iter;
+	gchar *ip_address;
+
+	gtk_tree_view_get_cursor (treeview, &path, NULL);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter, 0, &ip_address, -1);
+	
+	gtk_selection_data_set (data,
+				gdk_atom_intern ("x/dns-data", FALSE),
+				8,
+				ip_address,
+				strlen (ip_address) + 1);
+}
+
+void
+on_drag_data_received (GtkTreeView *treeview,
+		       GdkDragContext *context,
+		       gint x,
+		       gint y,
+		       GtkSelectionData *data,
+		       guint info,
+		       guint time)
+{
+	GtkTreeModel *model = gtk_tree_view_get_model (treeview);
+	GtkTreePath *dest_path;
+	GtkTreeViewDropPosition pos;
+	GtkTreeIter dest_iter, iter;
+
+	if (data->data == NULL || data->length == -1) {
+		gtk_drag_finish (context, FALSE, FALSE, GDK_CURRENT_TIME);
+		return;
+	}
+
+	if (gtk_tree_view_get_dest_row_at_pos (treeview, x, y, &dest_path, &pos)) {
+		if (!gtk_tree_model_get_iter (model, &dest_iter, dest_path)) {
+			gtk_drag_finish (context, FALSE, FALSE, GDK_CURRENT_TIME);
+			return;
+		}
+
+		if (pos == GTK_TREE_VIEW_DROP_BEFORE)
+			gtk_list_store_insert_before (GTK_LIST_STORE (model), &iter, &dest_iter);
+		else
+			gtk_list_store_insert_after (GTK_LIST_STORE (model), &iter, &dest_iter);
+	} else {
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+	}
+
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, data->data, -1);
+	gtk_drag_finish (context, TRUE, TRUE, GDK_CURRENT_TIME);
+
+	gst_dialog_modify (tool->main_dialog);
+}
