@@ -30,6 +30,7 @@
 #include "callbacks.h"
 
 #include "gst.h"
+#include "gst-hig-dialog.h"
 
 typedef struct _GstNetworkInterfaceDescription GstNetworkInterfaceDescription;
 
@@ -44,8 +45,12 @@ struct _GstNetworkInterfaceDescription {
 static GstNetworkInterfaceDescription gst_iface_desc [] = {
 	{ N_("Other type"),              GST_CONNECTION_OTHER,   "network.png",     "other_type", NULL },
 	{ N_("Ethernet LAN card"),       GST_CONNECTION_ETH,     "16_ethernet.xpm", "eth",        NULL },
-	{ N_("Wireless LAN card"),    GST_CONNECTION_WLAN,    "wavelan-16.png",  "wlan",       NULL },
+	{ N_("Ethernet LAN card"),       GST_CONNECTION_ETH,     "16_ethernet.xpm", "dc",         NULL },
+	{ N_("Ethernet LAN card"),       GST_CONNECTION_ETH,     "16_ethernet.xpm", "ed",         NULL },
+	{ N_("Ethernet LAN card"),       GST_CONNECTION_ETH,     "16_ethernet.xpm", "bfe",        NULL },
+	{ N_("Wireless LAN card"),       GST_CONNECTION_WLAN,    "wavelan-16.png",  "wlan",       NULL },
 	{ N_("Modem or transfer cable"), GST_CONNECTION_PPP,     "16_ppp.xpm",      "ppp",        NULL },
+	{ N_("Modem or transfer cable"), GST_CONNECTION_PPP,     "16_ppp.xpm",      "tun",        NULL },
 	{ N_("Parallel line"),           GST_CONNECTION_PLIP,    "16_plip.xpm",     "plip",       NULL },
 	{ N_("Infrared LAN"),            GST_CONNECTION_IRLAN,   "irda-16.png",     "irlan",      NULL },
 	{ N_("Loopback interface"),      GST_CONNECTION_LO,      "16_loopback.xpm", "lo",         NULL },
@@ -70,7 +75,7 @@ GtkItemFactoryEntry connection_popup_menu_items[] = {
 #define SET_BOOL(yy_prefix,xx) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), cxn->xx)
 #define SET_BOOL_NOT(yy_prefix,xx) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), !cxn->xx)
 #define SET_INT(yy_prefix,xx) gtk_range_set_value (GTK_RANGE (GTK_SCALE (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx))), cxn->xx)
-#define SET_DIAL_OPTION_MENU(yy_prefix, xx) gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), ((cxn->xx != NULL) && (strcmp (cxn->xx, "ATDP") == 0))?1:0)
+#define SET_DIAL_OPTION_MENU(yy_prefix, xx) gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), ((cxn->xx != NULL) && (g_ascii_strcasecmp (cxn->xx, "ATDP") == 0))?1:0)
 
 typedef struct {
 	GtkWidget *list;
@@ -126,6 +131,12 @@ connection_xml_save_boolean_to_node (xmlNode *node, gchar *node_name, gboolean b
 	connection_xml_save_str_to_node (node, node_name, bool? "1": "0");
 }
 
+static void
+connection_xml_destroy (xmlNodePtr node, gchar *node_name)
+{
+	gst_xml_element_destroy_children_by_name (node, node_name);
+}
+
 static gboolean
 connection_xml_wvsection_is_type (xmlNode *node, gchar *type)
 {
@@ -274,7 +285,7 @@ static gint
 connection_xml_wvsection_get_int (xmlNode *node, gchar *section_name, gchar *elem)
 {
 	gchar *str;
-	gint ret;
+	gint ret = -1;
 
 	str = connection_xml_wvsection_get_str (node, section_name, elem);
 	if (str) {
@@ -454,11 +465,10 @@ connection_list_model_new (void)
 	GtkListStore *store;
 
 	store = gtk_list_store_new (CONNECTION_LIST_COL_LAST,
+				    G_TYPE_BOOLEAN,
 				    GDK_TYPE_PIXBUF,
 				    G_TYPE_STRING,
 				    G_TYPE_STRING,
-				    G_TYPE_BOOLEAN,
-				    G_TYPE_STRING,
 				    G_TYPE_POINTER);
 	return GTK_TREE_MODEL (store);
 }
@@ -466,9 +476,20 @@ connection_list_model_new (void)
 static void
 connection_list_add_columns (GtkTreeView *treeview)
 {
-	GtkCellRenderer   *text_renderer, *pixbuf_renderer;
-	GtkTreeViewColumn *col;
+	GtkCellRenderer   *text_renderer, *pixbuf_renderer, *bool_renderer;
 	GtkTreeModel      *model = gtk_tree_view_get_model (treeview);
+	GtkTreeViewColumn *col;
+
+	/* Status */
+	bool_renderer = gtk_cell_renderer_toggle_new ();
+	g_signal_connect (G_OBJECT (bool_renderer), "toggled",
+			  G_CALLBACK (on_connection_toggled), treeview);
+	col = gtk_tree_view_column_new_with_attributes (_("Active"), bool_renderer,
+							"active", CONNECTION_LIST_COL_STAT,
+							NULL);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_clickable (col, TRUE);
+	gtk_tree_view_append_column (treeview, col);
 
 	/* Device type */
 	col = gtk_tree_view_column_new ();
@@ -499,27 +520,6 @@ connection_list_add_columns (GtkTreeView *treeview)
 	gtk_tree_view_column_set_sort_column_id (col, 2);
 
 	gtk_tree_view_append_column (treeview, col);
-
-	/* Status */
-	pixbuf_renderer = gtk_cell_renderer_toggle_new ();
-	g_signal_connect (G_OBJECT (pixbuf_renderer), "toggled", 
-			  G_CALLBACK (on_connection_toggled), treeview);
-	col = gtk_tree_view_column_new_with_attributes (_("Status"), pixbuf_renderer,
-							"active", CONNECTION_LIST_COL_STAT,
-							NULL);
-	gtk_tree_view_column_set_resizable (col, TRUE);
-	gtk_tree_view_column_set_clickable (col, TRUE);
-	gtk_tree_view_append_column (treeview, col);
-	                                                                    
-	/* Description */
-	text_renderer = gtk_cell_renderer_text_new ();
-	col = gtk_tree_view_column_new_with_attributes (_("Description"), text_renderer,
-							"text", CONNECTION_LIST_COL_DESCR,
-							NULL);
-	gtk_tree_view_column_set_resizable (col, TRUE);
-	gtk_tree_view_column_set_sort_column_id (col, 4);
-
-	gtk_tree_view_append_column (treeview, col);
 }
 
 static void
@@ -680,11 +680,10 @@ connection_list_append (GstConnection *cxn)
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+			    CONNECTION_LIST_COL_STAT,     connection_get_stat (cxn),
 			    CONNECTION_LIST_COL_DEV_PIX,  connection_get_dev_pixbuf (cxn),
 			    CONNECTION_LIST_COL_DEV_TYPE, connection_get_dev_type (cxn),
 			    CONNECTION_LIST_COL_DEVICE,   cxn->dev,
-			    CONNECTION_LIST_COL_STAT,     connection_get_stat (cxn),
-			    CONNECTION_LIST_COL_DESCR,    cxn->name,
 			    CONNECTION_LIST_COL_DATA,     cxn,
 			    -1);
 }
@@ -739,8 +738,8 @@ connection_list_update (void)
 }
 
 /* Polls the backend and updates the active interfaces */
-gboolean
-connection_poll_stat (GstTool *tool)
+static void
+connection_poll_stat_cb (GstDirectiveEntry *entry)
 {
 	gchar *dev;
 	gboolean enabled, found, valid;
@@ -753,13 +752,16 @@ connection_poll_stat (GstTool *tool)
 
 	/* if the tool is running remotely, we don't want this function to be run */
 	if (tool->remote_config)
-		return FALSE;
+		return;
 
-	doc = gst_tool_run_get_directive (tool, NULL, "list_ifaces", NULL);
+	doc = gst_tool_run_get_directive (entry->tool,
+					  entry->report_sign,
+					  entry->directive,
+					  NULL);
 
 	/* couldn't access the backend, return safely */
 	if (!doc)
-		return TRUE;
+		return;
 	
 	root = gst_xml_doc_get_root (doc);
 
@@ -799,7 +801,12 @@ connection_poll_stat (GstTool *tool)
 	}
 
 	gst_xml_doc_destroy (doc);
-	
+}
+
+gboolean
+connection_poll_stat (GstTool *tool)
+{
+	gst_tool_queue_directive (tool, connection_poll_stat_cb, NULL, NULL, NULL, "list_ifaces");
 	return TRUE;
 }
 
@@ -1030,6 +1037,7 @@ connection_default_gw_find_item (GtkWidget *omenu, gchar *dev)
 	for (l = g_object_get_data (G_OBJECT (omenu), "list");
 	     l; l = l->next) {
 		value = g_object_get_data (G_OBJECT (l->data), "value");
+
 		if (!strcmp (dev, value))
 			return l->data;
 	}
@@ -1057,9 +1065,15 @@ connection_default_gw_add (GstConnection *cxn)
 		return;
 
 	ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
+
+	g_return_if_fail (ui != NULL);
+	
 	omenu = ui->def_gw_omenu;
 	menu  = gtk_option_menu_get_menu (GTK_OPTION_MENU (omenu));
 
+	if (!cxn->gateway || !*cxn->gateway)
+		return;
+
 	if (connection_default_gw_find_item (omenu, dev))
 		return;
 	
@@ -1090,7 +1104,10 @@ connection_default_gw_remove (gchar *dev)
 	omenu = ui->def_gw_omenu;
 	menu  = gtk_option_menu_get_menu (GTK_OPTION_MENU (omenu));
 
-	g_return_if_fail ((item = connection_default_gw_find_item (omenu, dev)));
+	item = connection_default_gw_find_item (omenu, dev);
+
+	if (!item)
+		return;
 	
 	l = g_object_get_data (G_OBJECT (omenu), "list");
 	l = g_list_remove (l, item);
@@ -1110,6 +1127,8 @@ connection_default_gw_init (GstTool *tool, gchar *dev)
 
 	ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
 
+	g_return_if_fail (ui != NULL);
+
 	omenu = ui->def_gw_omenu;
 	menu  = gtk_option_menu_get_menu (GTK_OPTION_MENU (omenu));
 
@@ -1271,7 +1290,7 @@ connection_add_to_list (GstConnection *cxn)
 	connection_default_gw_add (cxn);
 }
 
-static gchar *
+gchar *
 connection_description_from_type (GstConnectionType type)
 {
 	gint i;
@@ -1311,8 +1330,17 @@ connection_get_ppp_from_node (xmlNode *node, GstConnection *cxn)
 		cxn->login = gst_xml_get_child_content (node, "login");
 		cxn->password = gst_xml_get_child_content (node, "password");
 		cxn->stupid = FALSE;
-		cxn->volume = 3;
-		cxn->dial_command = g_strdup ("ATDT");
+
+		/* FIXME: at this moment the xml may not have volume nor dial command */
+		if (gst_xml_element_find_first (node, "volume"))
+			cxn->volume = atoi (gst_xml_get_child_content (node, "volume"));
+		else
+			cxn->volume = 3;
+
+		cxn->dial_command = gst_xml_get_child_content (node, "dial_command");
+
+		if (!cxn->dial_command)
+			cxn->dial_command = g_strdup ("ATDT");
 	}
 
 	/* PPP advanced */
@@ -1334,24 +1362,31 @@ connection_get_ptp_from_node (xmlNode *node, GstConnection *cxn)
 gchar *
 connection_find_new_device (xmlNode *root, GstConnectionType type)
 {
-	xmlNode *node;
+	xmlDocPtr  doc;
+	xmlNodePtr node;
 	gchar *prefix, *dev, *numstr;
 	gint max;
 	gchar *devs[] = {
 		NULL,
-		"eth",
-		"wvlan",
-		"ppp",
-		"plip",
-		"irlan",
-		"lo",
+		"Ethernet",
+		NULL,
+		"Modem",
+		"Parallel",
+		"Infrared",
+		NULL,
 		NULL
 	};
 
-	prefix = devs[(gint) type];
-	if (!prefix)
+	if (!devs[(gint) type])
 		return g_strdup ("NIL");
 
+	doc = gst_tool_run_get_directive (tool, NULL, "get_interface_name", devs[(gint) type], NULL);
+
+	g_return_val_if_fail (doc != NULL, "NIL");
+
+	node = gst_xml_doc_get_root (doc);
+	prefix = gst_xml_get_child_content (node, "name");
+
 	max = -1;
 
 	for (node = gst_xml_element_find_first (root, "interface");
@@ -1619,7 +1654,6 @@ connection_set_bcast_and_network (GstConnection *cxn)
 static void
 empty_general (GstConnection *cxn)
 {
-	GET_STR ("connection_", name);
 	GET_BOOL ("status_", autoboot);
 	GET_BOOL ("status_", user);
 }
@@ -1692,9 +1726,10 @@ strempty (gchar *str)
 }
 
 static gboolean
-connection_validate (GstConnection *cxn)
+connection_validate (GstConnection *cxn, GtkWidget *parent)
 {
-	gchar *error = NULL;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
 	
 	switch (cxn->type) {
 	case GST_CONNECTION_ETH:
@@ -1703,49 +1738,63 @@ connection_validate (GstConnection *cxn)
 	case GST_CONNECTION_UNKNOWN:
 		if (cxn->ip_config == IP_MANUAL &&
 		    (strempty (cxn->address) ||
-		     strempty (cxn->netmask)))
-			error = _("The IP address or netmask for the interface "
-				  "was left empty. Please enter valid IP "
-				  "addresses in those fields to continue.");
+		     strempty (cxn->netmask))) {
+			primary_text   = _("Error in IP address");
+			secondary_text = _("The IP address or netmask for the interface "
+					   "was left empty. Please enter valid IP "
+					   "addresses in those fields to continue.");
+		}
+		
 		break;
 	case GST_CONNECTION_PLIP:
 		if (strempty (cxn->address) ||
-		    strempty (cxn->remote_address))
-			error = _("The IP address or remote address for the "
-				  "interface was left empty. Please enter valid "
-				  "IP addresses in those fields to continue.");
+		    strempty (cxn->remote_address)) {
+			primary_text   = _("Error in IP address");
+			secondary_text = _("The IP address or remote address for the "
+					   "interface was left empty. Please enter valid "
+					   "IP addresses in those fields to continue.");
+		}
+		
 		break;
 	case GST_CONNECTION_PPP:
-		if (!cxn->update_dns && strempty (cxn->dns1))
-			error = _("You chose to set the DNS servers for this "
-				  "connection manually, but left the IP "
-				  "address for the primary DNS empty. Please "
-				  "enter the IP for the primary DNS or uncheck "
-				  "the manual DNS option.");
-		else if (strempty (cxn->serial_port))
-			error = _("The modem device that the connection "
-				  "will use was left empty. Please enter "
-				  "a device or press \"autodetect\" to "
-				  "continue.");
-		else if (strempty (cxn->phone_number))
-			error = _("The phone number that the connection "
-				  "will use was left empty. Please enter "
-				  "a valid phone number to continue.");
+		if (!cxn->update_dns && strempty (cxn->dns1)) {
+			primary_text   = _("Error in DNS servers");
+			secondary_text = _("You chose to set the DNS servers for this "
+					   "connection manually, but left the IP "
+					   "address for the primary DNS empty. Please "
+					   "enter the IP for the primary DNS or uncheck "
+					   "the manual DNS option.");
+			
+		} else if (strempty (cxn->serial_port)) {
+			primary_text   = _("Invalid modem device");
+			secondary_text = _("The modem device that the connection "
+					   "will use was left empty. Please enter "
+					   "a device or press \"autodetect\" to "
+					   "continue.");
+		} else if (strempty (cxn->phone_number)) {
+			primary_text   = _("Invalid phone number");
+			secondary_text = _("The phone number that the connection "
+					   "will use was left empty. Please enter "
+					   "a valid phone number to continue.");
+		}
+		
 		break;
 	default:
 		break;
 	}
 
-	if (error) {
+	if (primary_text) {
 		GtkWidget *message;
 
-		message = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-						  GTK_DIALOG_MODAL,
-						  GTK_MESSAGE_ERROR,
-						  GTK_BUTTONS_OK,
-						  error);
-
+		message = gst_hig_dialog_new (GTK_WINDOW (parent),
+					      GTK_DIALOG_MODAL,
+					      GST_HIG_MESSAGE_ERROR,
+					      primary_text,
+					      secondary_text,
+					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					      NULL);
 		gtk_dialog_run (GTK_DIALOG (message));
+
 		gtk_widget_destroy (message);
 		return FALSE;
 	}
@@ -1782,7 +1831,6 @@ static void
 fill_general (GstConnection *cxn)
 {
 	gtk_label_set_text (GTK_LABEL (gst_dialog_get_widget (tool->main_dialog, "connection_dev")), cxn->dev);
-	SET_STR ("connection_", name);
 	SET_BOOL ("status_", autoboot);
 	SET_BOOL ("status_", user);
 }
@@ -1841,8 +1889,8 @@ fill_ip (GstConnection *cxn)
 
 	char *bootproto_labels[] = {
 		N_("Manual"),
-		N_("DHCP"),
-		N_("BOOTP")
+		N_("Automatic (DHCP)"),
+		N_("Automatic (BOOTP)")
 	};
 
 	omenu = gst_dialog_get_widget (tool->main_dialog, "connection_config");
@@ -1942,6 +1990,8 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 		fill_ppp (cxn);
 		fill_ppp_adv (cxn);
 
+		callbacks_check_dialer (GTK_WINDOW (window), tool);
+
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
 	} else if (cxn->type == GST_CONNECTION_WLAN) {
 		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
@@ -2004,6 +2054,20 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "advanced_page"));
 
 		fill_ip (cxn);
+	} else {
+		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
+					 PIXMAPS_DIR "/network.png");
+
+		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
+		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
+		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
+
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "ethernet_settings"));
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "ptp_settings"));
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "wireless_settings"));
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "ppp_settings"));
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "account_page"));
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "advanced_page"));
 	}
 
 	/* try to set the dialog at the minimum possible size */
@@ -2055,36 +2119,47 @@ void
 connection_configure_device (xmlNodePtr root, gchar *interface)
 {
 	xmlNodePtr node = gst_xml_element_find_first (root, "interface");
-	gchar *dev;
-	gboolean found = FALSE;
+	xmlNodePtr dev_node = NULL;
 	GstConnection *connection;
-	gchar *txt;
+	gboolean found = FALSE;
 	GtkWidget *dialog;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
+	gchar *dev;
 
-	for (node = gst_xml_element_find_first (root, "interface");
-	     node != NULL;
-	     node = gst_xml_element_find_next (node, "interface"))
-	{
-		dev = gst_xml_get_child_content (node, "dev");
+	if (strcmp (interface, "lo") != 0) {
+		for (node = gst_xml_element_find_first (root, "interface");
+		     node != NULL;
+		     node = gst_xml_element_find_next (node, "interface"))
+		{
+			dev = gst_xml_get_child_content (node, "dev");
 
-		if (strcmp (dev, interface) == 0) {
-			g_free (dev);
-			break;
-		}
+			if (strcmp (dev, interface) == 0)
+				dev_node = node;
 		
-		g_free (dev);
+			g_free (dev);
+		}
+
+		if (!dev_node) {
+			primary_text   = g_strdup (_("Nonexisting interface"));
+			secondary_text = g_strdup_printf (_("The interface \"%s\" doesn't exist."), interface);
+		}
+	} else {
+		primary_text   = g_strdup (_("Invalid interface"));
+		secondary_text = g_strdup (_("The loopback interface cannot be configured."));
 	}
 
-	if (node != NULL) {
-		connection = connection_new_from_node (node, FALSE);
+	if (!primary_text) {
+		connection = connection_new_from_node (dev_node, FALSE);
 		connection_configure (connection);
 	} else {
-		txt = g_strdup_printf (_("The interface %s doesn't exist."), interface);
-		dialog = gtk_message_dialog_new (NULL,
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_QUESTION,
-						 GTK_BUTTONS_CLOSE,
-						 txt);
+		dialog = gst_hig_dialog_new (NULL,
+					     GTK_DIALOG_MODAL,
+					     GST_HIG_MESSAGE_ERROR,
+					     primary_text,
+					     secondary_text,
+					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					     NULL);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		exit (0);
 	}
@@ -2133,30 +2208,37 @@ connection_save_to_node (GstConnection *cxn, xmlNode *root)
 		connection_xml_save_boolean_to_node (node, "update_dns", cxn->update_dns);
 
 	/* TCP/IP general paramaters */
-	connection_set_bcast_and_network (cxn);
-	connection_xml_save_str_to_node (node, "address", cxn->address);
-	connection_xml_save_str_to_node (node, "netmask", cxn->netmask);
-	connection_xml_save_str_to_node (node, "broadcast", cxn->broadcast);
-	connection_xml_save_str_to_node (node, "network", cxn->network);
-	connection_xml_save_str_to_node (node, "gateway", cxn->gateway);
-
 	s = connection_config_type_to_str (cxn->ip_config);
 	connection_xml_save_str_to_node (node, "bootproto", s);
 	g_free (s);
 
+	if (cxn->ip_config == IP_MANUAL) {
+		connection_set_bcast_and_network (cxn);
+		connection_xml_save_str_to_node (node, "address", cxn->address);
+		connection_xml_save_str_to_node (node, "netmask", cxn->netmask);
+		connection_xml_save_str_to_node (node, "broadcast", cxn->broadcast);
+		connection_xml_save_str_to_node (node, "network", cxn->network);
+		connection_xml_save_str_to_node (node, "gateway", cxn->gateway);
+	} else {
+		connection_xml_destroy (node, "address");
+		connection_xml_destroy (node, "netmask");
+		connection_xml_destroy (node, "broadcast");
+		connection_xml_destroy (node, "network");
+		connection_xml_destroy (node, "gateway");
+	}
+
 	/* PPP stuff */
 	if (cxn->type == GST_CONNECTION_PPP) {
-		if (!cxn->wvsection)
-			cxn->wvsection = connection_wvsection_name_generate (cxn->dev, root);
-		connection_xml_save_str_to_node (node, "wvsection", cxn->wvsection);
-		
-		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "phone", cxn->phone_number);
-		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "external_line", cxn->external_line);
-		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "login", cxn->login);
-		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "password", cxn->password);
-		connection_xml_wvsection_save_boolean_to_node (root, cxn->wvsection, "stupid", cxn->stupid);
-		connection_xml_wvsection_save_int_to_node (root, cxn->wvsection, "volume", cxn->volume);
-		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "dial_command", cxn->dial_command);
+		s = g_strdup_printf ("%i", cxn->volume);
+		connection_xml_save_str_to_node (node, "volume", s);
+		g_free (s);
+
+		connection_xml_save_str_to_node (node, "phone_number", cxn->phone_number);
+		connection_xml_save_str_to_node (node, "external_line", cxn->external_line);
+		connection_xml_save_str_to_node (node, "login", cxn->login);
+		connection_xml_save_str_to_node (node, "password", cxn->password);
+		connection_xml_save_str_to_node (node, "dial_command", cxn->dial_command);
+		connection_xml_save_boolean_to_node (node, "stupid", cxn->stupid);
 
 		/* PPP advanced */
 		connection_xml_save_boolean_to_node (node, "persist", cxn->persist);
@@ -2166,6 +2248,19 @@ connection_save_to_node (GstConnection *cxn, xmlNode *root)
 		connection_xml_save_str_to_node (node, "dns1", cxn->dns1);
 		connection_xml_save_str_to_node (node, "dns2", cxn->dns2);
 		connection_xml_save_str_to_node (node, "ppp_options", cxn->ppp_options);
+
+		if (!cxn->wvsection)
+			cxn->wvsection = connection_wvsection_name_generate (cxn->dev, root);
+		connection_xml_save_str_to_node (node, "wvsection", cxn->wvsection);
+		
+		/* FIXME: at the moment we need to keep this, but we should avoid wvdial eventually */
+		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "phone", cxn->phone_number);
+		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "external_line", cxn->external_line);
+		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "login", cxn->login);
+		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "password", cxn->password);
+		connection_xml_wvsection_save_boolean_to_node (root, cxn->wvsection, "stupid", cxn->stupid);
+		connection_xml_wvsection_save_int_to_node (root, cxn->wvsection, "volume", cxn->volume);
+		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "dial_command", cxn->dial_command);
 	}
 
 	/* PtP */
@@ -2257,7 +2352,7 @@ connection_list_select_connection (GstConnection *cxn)
 }
 
 gboolean
-connection_config_save (GstConnection *cxn, gboolean add_to_list)
+connection_config_save (GstConnection *cxn, GtkWidget *parent, gboolean add_to_list)
 {
 	GstConnection *tmp = g_new0 (GstConnection, 1);
 
@@ -2269,7 +2364,7 @@ connection_config_save (GstConnection *cxn, gboolean add_to_list)
 	tmp->tmp_ip_config = cxn->tmp_ip_config;
 	
 	connection_empty_gui (tmp);
-	if (!connection_validate (tmp)) {
+	if (!connection_validate (tmp, parent)) {
 		connection_free (tmp);
 		return FALSE;
 	}
@@ -2321,3 +2416,15 @@ connection_get_count (GstTool *tool)
 
 	return count;
 }
+
+void
+connection_apply_and_activate (GstTool *tool, GstConnection *cxn)
+{
+	gtk_signal_emit_by_name (GTK_OBJECT (tool->main_dialog), "apply", tool);
+	gst_tool_run_set_directive (tool,
+				    NULL, NULL,
+				    "enable_iface",
+				    (cxn->file)? cxn->file : cxn->dev,
+				    "1",
+				    NULL);
+}
