@@ -48,6 +48,8 @@ GstDialogSignal signals[] = {
 	{ "connection_add",          "clicked",         G_CALLBACK (on_connection_add_clicked) },
 	{ "connection_delete",       "clicked",         G_CALLBACK (on_connection_delete_clicked) },
 	{ "connection_configure",    "clicked",         G_CALLBACK (on_connection_configure_clicked) },
+	{ "connection_activate",     "clicked",         G_CALLBACK (on_connection_activate_button_clicked) },
+	{ "connection_deactivate",   "clicked",         G_CALLBACK (on_connection_deactivate_button_clicked) },
 	{ "connection_def_gw_omenu", "changed",         G_CALLBACK (gst_dialog_modify_cb) },
 	{ "domain",                  "changed",         G_CALLBACK (gst_dialog_modify_cb) },
 /*	{ "ip",                      "changed",         G_CALLBACK (gst_dialog_modify_cb) },*/
@@ -80,14 +82,14 @@ GstDialogSignal signals[] = {
 	{ "network_connection_plip_page1",   "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_ppp_page1",    "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_ppp_page2",    "next",   G_CALLBACK (on_network_druid_page_next) },
-	{ "network_connection_page_name",         "next",   G_CALLBACK (on_network_druid_page_next) },
+	{ "network_connection_page_activate", "next",   G_CALLBACK (on_network_druid_page_next) },
 	{ "network_connection_page2",        "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_wireless_page",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_other_page1",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_plip_page1",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_ppp_page1",    "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_ppp_page2",    "back",   G_CALLBACK (on_network_druid_page_back) },
-	{ "network_connection_page_name",    "back",   G_CALLBACK (on_network_druid_page_back) },
+	{ "network_connection_page_activate", "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_page_finish",  "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_wireless_device_entry", "changed", G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_essid", "changed", G_CALLBACK (on_network_druid_entry_changed) },
@@ -101,7 +103,6 @@ GstDialogSignal signals[] = {
 	{ "network_connection_ppp_login",    "changed",   G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_ppp_passwd1",  "changed",   G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_ppp_passwd2",  "changed",   G_CALLBACK (on_network_druid_entry_changed) },
-	{ "network_connection_name",         "changed",   G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_page_finish",  "finish",    G_CALLBACK (on_network_druid_finish) },
 	{ "network_connection_other_ip_address", "focus_out_event", G_CALLBACK (on_network_druid_ip_address_focus_out) },
 
@@ -119,7 +120,6 @@ GstDialogSignal signals[] = {
 	{ "ip_address", "focus_out_event", G_CALLBACK (on_ip_address_focus_out) },
 	{ "ip_netmask", "focus_out_event", G_CALLBACK (on_ip_address_focus_out) },
 	{ "ppp_update_dns", "toggled", G_CALLBACK (on_ppp_update_dns_toggled) },
-	{ "connection_name", "changed", G_CALLBACK (on_connection_modified) },
 	{ "status_autoboot", "toggled", G_CALLBACK (on_connection_modified) },
 	{ "status_user", "toggled", G_CALLBACK (on_connection_modified) },
 	{ "wlan_essid", "changed", G_CALLBACK (on_connection_modified) },
@@ -148,38 +148,14 @@ GstDialogSignal signals[] = {
 };
 
 GstDialogSignal signals_after[] = {
-	{ "network_connection_page1", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_page2", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page2",         "prepare", G_CALLBACK (on_network_druid_page_prepare) },
 	{ "network_connection_wireless_page", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_other_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_plip_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_ppp_page1", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_ppp_page2", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_page_name", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ "network_connection_page_finish", "prepare",   G_CALLBACK (on_network_druid_page_prepare) },
-	{ NULL }
-};
-
-static const GstWidgetPolicy policies[] = {
-	/* Name                      Basic                        Advanced           Require-Root   Default */
-	{ "connections_bbox",        GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "connection_delete",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "connection_configure",    GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-/*	{ "connection_activate",     GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "connection_deactivate",   GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },*/
-	{ "connection_def_gw_hbox",  GST_WIDGET_MODE_HIDDEN,      GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "statichost_table",        GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "statichost_add",          GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "statichost_delete",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "samba_use",               GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "description_label",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-	{ "smbdesc",                 GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-	{ "workgroup_label",         GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-	{ "workgroup",               GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-	{ "wins_use",       GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, FALSE },
-/*	{ "samba_frame",             GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },*/
-	{ "winsserver",              GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "network_profiles_button", GST_WIDGET_MODE_SENSITIVE,   GST_WIDGET_MODE_SENSITIVE, TRUE, TRUE  },
+	{ "network_connection_other_page1",   "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_plip_page1",    "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_ppp_page1",     "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_ppp_page2",     "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page_activate", "prepare", G_CALLBACK (on_network_druid_page_prepare) },
+	{ "network_connection_page_finish",   "prepare", G_CALLBACK (on_network_druid_page_prepare) },
 	{ NULL }
 };
 
@@ -188,55 +164,9 @@ static GstReportHookEntry report_hooks[] = {
 	{ NULL,                      NULL,                           -1,                   FALSE, NULL }
 };
 
-static void
-update_notebook_complexity (GstTool *tool, GstDialogComplexity complexity)
-{
-	GtkWidget *hosts;
-	GtkNotebook *notebook;
-	gint pageno;
-
-	notebook = GTK_NOTEBOOK (gst_dialog_get_widget (tool->main_dialog, "network_admin_notebook"));
-	hosts    = gst_dialog_get_widget (tool->main_dialog, "hosts_container");
-	pageno   = gtk_notebook_page_num (notebook, hosts);
-
-	switch (complexity) {
-	case GST_DIALOG_BASIC:
-		g_return_if_fail (pageno != -1);
-
-		if (gtk_notebook_get_current_page (notebook) == pageno)
-			gtk_notebook_set_current_page (notebook, pageno - 1);
-		gtk_widget_ref (hosts);
-		gtk_widget_unparent (hosts);
-		gtk_notebook_remove_page (notebook, pageno);
-		break;
-	case GST_DIALOG_ADVANCED:
-		if (pageno != -1)
-			return;
-
-		gtk_notebook_append_page (notebook, hosts,
-					  gtk_label_new (_("Hosts")));
-		gtk_widget_unref (hosts);
-		break;
-	default:
-		g_warning ("update_notebook_complexity: Unsupported complexity.");
-	}
-}
-
-static void
-update_complexity (GstDialog *dialog, gpointer data)
-{
-	update_notebook_complexity (dialog->tool, dialog->complexity);
-	connection_update_complexity (dialog->tool, dialog->complexity);
-}
-
 static void
 connect_signals (GstDialog *main_dialog, GstDialogSignal *sigs, GstDialogSignal *sigs_after)
 {
-	GtkWidget *w;
-
-	g_signal_connect (G_OBJECT (main_dialog), "complexity_change",
-			  G_CALLBACK (update_complexity), NULL);
-
 	gst_dialog_connect_signals (main_dialog, sigs);
 	gst_dialog_connect_signals_after (main_dialog, sigs_after);
 }
@@ -303,7 +233,7 @@ main (int argc, char *argv[])
 
 		connect_signals (tool->main_dialog, signals, signals_after);
 		init_editable_filters (tool->main_dialog);
-		gst_dialog_set_widget_policies (tool->main_dialog, policies);
+		on_network_admin_show (NULL, tool);
 
 		gst_tool_main_with_hidden_dialog (tool, TRUE);
 
@@ -322,13 +252,9 @@ main (int argc, char *argv[])
 		gst_dialog_add_apply_hook (tool->main_dialog, callbacks_check_gateway_hook,      tool);
 		gst_tool_add_report_hooks (tool, report_hooks);
 		gst_tool_set_xml_funcs (tool, transfer_xml_to_gui, transfer_gui_to_xml, NULL);
-		gst_dialog_enable_complexity (tool->main_dialog);
-		gst_dialog_set_widget_policies (tool->main_dialog, policies);
 
 		init_editable_filters (tool->main_dialog);
-
 		on_network_admin_show (NULL, tool);
-		update_complexity (tool->main_dialog, NULL);
 
 		gst_tool_main (tool, TRUE);
 		
@@ -336,7 +262,8 @@ main (int argc, char *argv[])
 			g_signal_emit_by_name (G_OBJECT (gst_dialog_get_widget (tool->main_dialog, "connection_add")),
 					       "clicked",
 					       NULL);
-
+		on_network_notebook_switch_page (gst_dialog_get_widget (tool->main_dialog, "network_admin_notebook"),
+						 NULL, 0, NULL);
 		gtk_main ();
 	}
 		
