@@ -30,7 +30,7 @@
 #include <math.h>
 #include <string.h>
 
-#include "xst.h"
+#include "gst.h"
 #include "time-tool.h"
 
 #include "tz.h"
@@ -38,7 +38,7 @@
 #include "tz-map.h"
 
 
-extern XstTimeTool *tool;
+extern GstTimeTool *tool;
 
 
 /* --- Forward declarations of internal functions --- */
@@ -48,18 +48,21 @@ static TzLocation *e_tz_map_location_from_point (ETzMap *tzmap, EMapPoint *point
 static gboolean flash_selected_point (gpointer data);
 static gboolean motion (GtkWidget *widget, GdkEventMotion *event, gpointer data);
 static gboolean button_pressed (GtkWidget *w, GdkEventButton *event, gpointer data);
-
+static gboolean update_map (GtkWidget *w, gpointer data);
+static gboolean out_map (GtkWidget *w,GdkEventCrossing *event, gpointer data);
 
 ETzMap *
-e_tz_map_new (XstTimeTool *tool)
+e_tz_map_new (GstTimeTool *tool)
 {
 	ETzMap *tzmap;
 	GPtrArray *locs;
 	TzLocation *tzl;
+	GtkWidget *location_combo;
+	GtkWidget *location_entry;
 	int i;
 
 	tzmap = g_new0 (ETzMap, 1);
-	tzmap->tool = XST_TOOL (tool);
+	tzmap->tool = GST_TOOL (tool);
 	tzmap->tzdb = tz_load_db ();
 	if (!tzmap->tzdb)
 		g_error ("Unable to load system timezone database.");
@@ -68,6 +71,9 @@ e_tz_map_new (XstTimeTool *tool)
 	if (!tzmap->map)
 		g_error ("Unable to create map widget.");
 
+	gtk_widget_set_events (GTK_WIDGET (tzmap->map), gtk_widget_get_events (GTK_WIDGET (tzmap->map)) | 
+	      GDK_LEAVE_NOTIFY_MASK | GDK_VISIBILITY_NOTIFY_MASK);
+	
 	locs = tz_get_locations (tzmap->tzdb);
 	
 	for (i = 0; g_ptr_array_index(locs, i); i++)
@@ -82,6 +88,13 @@ e_tz_map_new (XstTimeTool *tool)
 			 G_CALLBACK (motion), (gpointer) tzmap);
 	g_signal_connect(G_OBJECT(tzmap->map), "button-press-event",
 			 G_CALLBACK (button_pressed), (gpointer) tzmap);
+        g_signal_connect(G_OBJECT (tzmap->map), "leave-notify-event",
+	                 G_CALLBACK (out_map), (gpointer) tzmap);
+	
+	location_combo = gst_dialog_get_widget (tzmap->tool->main_dialog, "location_combo");
+	location_entry = GTK_COMBO (location_combo)->entry;
+	g_signal_connect (G_OBJECT (location_entry), "changed",
+	                 G_CALLBACK (update_map), (gpointer) tzmap);
 	
 	return tzmap;
 }
@@ -152,11 +165,23 @@ e_tz_map_set_tz_from_name (ETzMap *tzmap, gchar *name)
 	tzmap->point_selected =
 	  e_map_get_closest_point (tzmap->map, l_longitude, l_latitude, FALSE);
 
-	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (xst_dialog_get_widget (tzmap->tool->main_dialog, "location_combo"))->entry),
+	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (gst_dialog_get_widget (tzmap->tool->main_dialog, "location_combo"))->entry),
 			    tz_location_get_zone (e_tz_map_location_from_point (tzmap, tzmap->point_selected)));
 }
 
-
+static gboolean
+update_map (GtkWidget *w, gpointer data)
+{
+	ETzMap *tzmap;
+   
+	tzmap = (ETzMap *) data;
+   
+	if (strlen (gtk_entry_get_text (GTK_ENTRY(w))) > 0)
+		e_tz_map_set_tz_from_name (tzmap, g_strdup (gtk_entry_get_text (GTK_ENTRY(w))));
+      
+	return TRUE;
+}
+                                 
 gchar *
 e_tz_map_get_selected_tz_name (ETzMap *tzmap)
 {
@@ -164,7 +189,7 @@ e_tz_map_get_selected_tz_name (ETzMap *tzmap)
 	GtkWidget  *location_entry;
 	gchar      *entry_text;
 
-	location_combo = xst_dialog_get_widget (tzmap->tool->main_dialog, "location_combo");
+	location_combo = gst_dialog_get_widget (tzmap->tool->main_dialog, "location_combo");
 	location_entry = GTK_COMBO (location_combo)->entry;
 
 	entry_text     = (gchar *) gtk_entry_get_text (GTK_ENTRY (location_entry));
@@ -251,13 +276,36 @@ motion (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 	/* e_tz_map_location_from_point() can in theory return NULL, but in
 	 * practice there are no reasons why it should */
 
-	gtk_label_set_text (GTK_LABEL (((XstTimeTool *) tzmap->tool)->map_hover_label),
+	gtk_label_set_text (GTK_LABEL (((GstTimeTool *) tzmap->tool)->map_hover_label),
 			    tz_location_get_zone (e_tz_map_location_from_point (tzmap, tzmap->point_hover)));
 
 	return TRUE;
 }
 
 
+static gboolean
+out_map (GtkWidget *w, GdkEventCrossing *event, gpointer data)
+{
+	ETzMap *tzmap;
+	char *old_zone;
+   
+	tzmap = (ETzMap *) data;
+
+	if (event->mode != GDK_CROSSING_NORMAL)
+		return FALSE;
+   
+	if (tzmap->point_hover && tzmap->point_hover != tzmap->point_selected)
+		e_map_point_set_color_rgba (tzmap->map, tzmap->point_hover, TZ_MAP_POINT_NORMAL_RGBA);
+
+	tzmap->point_hover = NULL;
+   
+	gtk_label_get (GTK_LABEL (((GstTimeTool *) tzmap->tool)->map_hover_label), &old_zone);
+	if (strcmp (old_zone, ""))
+		gtk_label_set_text (GTK_LABEL (((GstTimeTool *) tzmap->tool)->map_hover_label), "");
+   
+	return TRUE;
+}
+   
 static gboolean
 button_pressed (GtkWidget *w, GdkEventButton *event, gpointer data)
 {
@@ -287,7 +335,7 @@ button_pressed (GtkWidget *w, GdkEventButton *event, gpointer data)
 						    TZ_MAP_POINT_NORMAL_RGBA);
 		tzmap->point_selected = tzmap->point_hover;
 
-		location_combo = xst_dialog_get_widget (tzmap->tool->main_dialog, "location_combo");
+		location_combo = gst_dialog_get_widget (tzmap->tool->main_dialog, "location_combo");
 		location_entry = GTK_COMBO (location_combo)->entry;
 		tz_location    = e_tz_map_location_from_point (tzmap, tzmap->point_selected);
 
@@ -298,6 +346,6 @@ button_pressed (GtkWidget *w, GdkEventButton *event, gpointer data)
 			gtk_entry_set_text (GTK_ENTRY (location_entry), entry_text_new);
 		}
 	}
-	
+
 	return TRUE;
 }
