@@ -81,18 +81,21 @@ on_table_clicked (GtkTreeSelection *selection, gpointer data)
 {
 	GtkTreeView *treeview;
 	int cont;
+	gboolean active;
 
 	treeview = (GtkTreeView *) data;
 	cont = 0;
 
 	gtk_tree_selection_selected_foreach (selection, counter , &cont);
+
+	active = (cont > 0);
    
 	if (users_table == GTK_WIDGET (treeview))
-		actions_set_sensitive (NODE_USER, TRUE);
+		actions_set_sensitive (NODE_USER, active);
 	else if (groups_table == GTK_WIDGET (treeview))
-		actions_set_sensitive (NODE_GROUP, TRUE);
+		actions_set_sensitive (NODE_GROUP, active);
 	else
-		actions_set_sensitive (NODE_PROFILE, TRUE);
+		actions_set_sensitive (NODE_PROFILE, active);
 	
 	if (cont > 1)
 	{
@@ -117,28 +120,35 @@ on_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer gd
 
 	cont = 0;
 
+	if (event->type == GDK_2BUTTON_PRESS || event->type == GDK_3BUTTON_PRESS) {
+		if (GTK_WIDGET (treeview) == groups_table)
+			on_group_settings_clicked (NULL, NULL);
+		else if (GTK_WIDGET (treeview) == users_table)
+			on_user_settings_clicked (NULL, NULL);
+	}
+	
 	selection = gtk_tree_view_get_selection (treeview);
 	gtk_tree_selection_selected_foreach (selection, counter , &cont);
 	
-	if (event->button == 3)
-	{
+	if (event->button == 3)	{
 		gtk_widget_grab_focus (GTK_WIDGET (treeview));
-		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL))
-		{
-			if (cont < 1)
-			{
+		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL)) {
+			if (cont < 1) {
 				gtk_tree_selection_unselect_all (selection);
 				gtk_tree_selection_select_path (selection, path);
 			}
 
-			if (cont > 1)
-				gtk_widget_set_sensitive (gtk_item_factory_get_widget_by_action (factory,
-												 POPUP_SETTINGS),
-							  FALSE);
-			else
-				gtk_widget_set_sensitive (gtk_item_factory_get_widget_by_action (factory,
-												 POPUP_SETTINGS),
-							  TRUE);
+			if (cont > 1) {
+				gtk_widget_set_sensitive (
+					gtk_item_factory_get_widget_by_action (factory,
+									       POPUP_SETTINGS),
+					FALSE);
+			} else {
+				gtk_widget_set_sensitive (
+					gtk_item_factory_get_widget_by_action (factory,
+									       POPUP_SETTINGS),
+					TRUE);
+			}
 
 			gtk_tree_path_free (path);
 			
@@ -553,12 +563,14 @@ void
 on_profile_settings_ok_clicked (GtkButton *button, gpointer data)
 {
 	GtkWidget *dialog = gst_dialog_get_widget (tool->main_dialog, "profile_settings_dialog");
-	xmlNodePtr node = g_object_get_data (G_OBJECT (dialog), "data");
-	gchar *error = profile_settings_check ();
+	xmlNodePtr node   = g_object_get_data (G_OBJECT (dialog), "data");
+	gchar *error      = profile_settings_check ();
 
 	if (error != NULL) {
 		/* the profile cannot be added/modified, show the error and exit */
-		show_error_message ("profile_settings_dialog", error);
+		show_error_message ("profile_settings_dialog",
+				    _("Error saving profile"),
+				    error);
 	} else {
 		/* the profile is OK, we can add/modify it */
 		if (node == NULL) {
@@ -573,6 +585,9 @@ on_profile_settings_ok_clicked (GtkButton *button, gpointer data)
 
 		profiles_table_update_content ();
 
+		/* mark dialog buttons as unsensitive */
+		actions_set_sensitive (NODE_PROFILE, FALSE);
+
 		gst_dialog_modify (tool->main_dialog);
 	}
 }
@@ -591,6 +606,9 @@ on_profile_new_clicked (GtkButton *button, gpointer data)
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Create New profile"));
 
+	if (!GTK_WIDGET_VISIBLE (gst_dialog_get_widget (tool->main_dialog, "user_optional_settings")))
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "profile_settings_password"));
+
 	gtk_widget_show (dialog);
 }
 
@@ -625,6 +643,9 @@ on_profile_settings_clicked (GtkButton *button, gpointer data)
 	g_free (profile_name);
 	g_free (window_title);
 
+	if (!GTK_WIDGET_VISIBLE (gst_dialog_get_widget (tool->main_dialog, "user_optional_settings")))
+		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "profile_settings_password"));
+
 	gtk_widget_show (dialog);
 }
 
@@ -662,16 +683,15 @@ on_profile_delete_clicked (GtkButton *button, gpointer user_data)
 }
 
 /* general callbacks */
-
 void
-on_add_remove_button_clicked (GtkButton *button, gpointer user_data)
+on_add_remove_button_clicked (GtkButton *button, gpointer data)
 {
 	GtkTreeView *in, *out;
 	GtkTreeSelection *selection;
-	GtkTreeIter iter;
-	GtkTreeModel *model;
-	GList *in_list, *out_list;
-	GList *element;
+	GtkTreeIter iter_in, iter_out;
+	GtkTreeModel *model_in, *model_out;
+	gchar *group;
+	gboolean valid;
 	
 	g_return_if_fail (gst_tool_get_access (tool));
 	
@@ -680,38 +700,25 @@ on_add_remove_button_clicked (GtkButton *button, gpointer user_data)
 	
 	g_return_if_fail (in != NULL || out != NULL);
 
-	in_list = g_object_get_data (G_OBJECT (in), "list");
-	out_list = g_object_get_data (G_OBJECT (out), "list");
-	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (in));
-	model = gtk_tree_view_get_model (in);
-	gtk_tree_model_get_iter_first (model, &iter);
-	
-	do {
-		if (gtk_tree_selection_iter_is_selected (selection, &iter)) {
-			/* gets the user that is being removed from the 'in' list */
-			gtk_tree_model_get (model, &iter,
-	                                    1, &element,
-	                                    -1);
-			/* adds the user to the 'out' list */
-                        out_list = g_list_insert_sorted (out_list, element->data, my_strcmp);
-			
-			/* removes the user from the 'in' list */
-			in_list = g_list_remove (in_list, element->data);
+	model_in = gtk_tree_view_get_model (in);
+	model_out = gtk_tree_view_get_model (out);
+
+	valid = gtk_tree_model_get_iter_first (model_in, &iter_in);
+
+	while (valid) {
+		if (gtk_tree_selection_iter_is_selected (selection, &iter_in)) {
+			gtk_tree_model_get (model_in, &iter_in, 0, &group, -1);
+
+			gtk_tree_store_append (GTK_TREE_STORE (model_out), &iter_out, NULL);
+			gtk_tree_store_set (GTK_TREE_STORE (model_out), &iter_out, 0, group, -1);
+
+			valid = gtk_tree_store_remove (GTK_TREE_STORE (model_in), &iter_in);
+		} else {
+			valid = gtk_tree_model_iter_next (model_in, &iter_in);
 		}
-	} while (gtk_tree_model_iter_next (model, &iter));
-	
-	/* reattach GLists to GtkTreeViews */
-	g_object_set_data (G_OBJECT (in), "list", in_list);
-	g_object_set_data (G_OBJECT (out), "list", out_list);
+	}
 
-	/* Refresh the 'in' and 'out' lists */
-	clear_gtk_tree_list (in);
-	clear_gtk_tree_list (out);
-	populate_gtk_tree_list (in, in_list);
-	populate_gtk_tree_list (out, out_list);
-	
-	/* sets unsensitive the button again */
 	gtk_widget_set_sensitive (GTK_WIDGET (button), FALSE);
 }
 
@@ -730,6 +737,56 @@ on_list_select_row (GtkTreeSelection *selection, gpointer data)
 	gtk_widget_set_sensitive (widget, TRUE);
 }
 
+void
+on_list_drag_data_get (GtkTreeView *treeview,
+		       GdkDragContext *context,
+		       GtkSelectionData *selection,
+		       guint info,
+		       guint time,
+		       gpointer data)
+{
+	GtkTreeModel *model = gtk_tree_view_get_model (treeview);
+	GtkTreePath *path;
+	GtkTreeIter iter;
+	gchar *group;
+
+	gtk_tree_view_get_cursor (treeview, &path, NULL);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter, 0, &group, -1);
+	
+	gtk_selection_data_set (selection,
+				gdk_atom_intern ("x/selection-data", FALSE),
+				8, group, strlen (group) + 1);
+}
+
+void
+on_list_drag_data_received (GtkTreeView *dest_treeview,
+			    GdkDragContext *context,
+			    gint x,
+			    gint y,
+			    GtkSelectionData *selection,
+			    guint info,
+			    guint time,
+			    gpointer data)
+{
+	GtkTreeModel *model = gtk_tree_view_get_model (dest_treeview);
+	GtkTreeIter iter;
+
+	if (selection->data == NULL || selection->length == -1) {
+		gtk_drag_finish (context, FALSE, FALSE, GDK_CURRENT_TIME);
+		return;
+	}
+
+	gtk_tree_store_append (GTK_TREE_STORE (model), &iter, NULL);
+	gtk_tree_store_set (GTK_TREE_STORE (model),
+			    &iter,
+			    0, selection->data,
+			    -1);
+	
+	gtk_drag_finish (context, TRUE, TRUE, GDK_CURRENT_TIME);
+	gst_dialog_modify (tool->main_dialog);
+}
+
 /* Helpers .*/
 
 void
