@@ -28,6 +28,7 @@
 #include <gnome.h>
 
 #include "gst.h"
+#include "gst-hig-dialog.h"
 #include "groups-table.h"
 #include "table.h"
 #include "callbacks.h"
@@ -37,14 +38,6 @@
 
 extern GstTool *tool;
 
-static void
-create_users_lists (xmlNodePtr node, GList **group_settings_all_list, GList **group_settings_members_list)
-{
-	*group_settings_members_list = get_group_users (node);
-	*group_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("login", NODE_USER), *group_settings_members_list);
-}
-
-
 static void
 create_users_gtk_trees (void)
 {
@@ -53,25 +46,16 @@ create_users_gtk_trees (void)
 	GtkWidget *add_button, *remove_button;
 	GtkTreeSelection *selection;
 	GtkSizeGroup *sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
+	GtkTargetEntry target = { "user", GTK_TARGET_SAME_APP, 1 };
 	
 	/* We create the widgets, connect signals and attach data if they haven't been created already */
 	if (g_object_get_data (G_OBJECT (group_settings_all), "button") == NULL) {
-		create_gtk_tree_list (group_settings_all);
+		create_gtk_tree_list (group_settings_all, target);
 		g_object_set_data (G_OBJECT (group_settings_all), "button", "group_settings_add");
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (group_settings_all));
-		g_signal_connect (G_OBJECT (selection),
-		                  "changed",
-		                  G_CALLBACK (on_list_select_row),
-		                  NULL);
 
-		create_gtk_tree_list (group_settings_members);
+		create_gtk_tree_list (group_settings_members, target);
 		g_object_set_data (G_OBJECT (group_settings_members), "button", "group_settings_remove");
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (group_settings_members));
-		g_signal_connect (G_OBJECT (selection),
-		                  "changed",
-		                  G_CALLBACK (on_list_select_row),
-		                  NULL);
-		
+
 		/* We also need to attach some data to the 'add' and 'remove' buttons */
 		add_button = gst_dialog_get_widget (tool->main_dialog, "group_settings_add");
 		g_object_set_data (G_OBJECT (add_button), "in", group_settings_all);
@@ -95,18 +79,13 @@ group_new_prepare (ug_data *gd)
 	GtkWidget *group_settings_members = gst_dialog_get_widget (tool->main_dialog, "group_settings_members");
 	GtkWidget *widget;
 	gchar     *buf;
-	GList *group_settings_members_list = NULL;
 	GList *group_settings_all_list = NULL;
 	
 	/* Fill all users list, don't exclude anything */
 	create_users_gtk_trees ();
-	create_users_lists (gd->node, &group_settings_all_list, &group_settings_members_list);
+	group_settings_all_list = get_list_from_node ("login", NODE_USER);
 	populate_gtk_tree_list (GTK_TREE_VIEW (group_settings_all), group_settings_all_list);
 	
-	/* Attach the GLists to the GtkTreeViews */
-	g_object_set_data (G_OBJECT (group_settings_all), "list", group_settings_all_list);
-	g_object_set_data (G_OBJECT (group_settings_members), "list", group_settings_members_list);
-
 	widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_dialog");
 	gtk_window_set_title (GTK_WINDOW (widget), _("Create New Group"));
 
@@ -156,21 +135,47 @@ group_settings_dialog_close (void)
 	gtk_widget_hide (widget);
 }
 
+static gboolean
+is_group_root (xmlNodePtr node)
+{
+	gchar *group;
+
+	if (strcmp (node->name, "groupdb") == 0) {
+		/* node is set to userdb node, this means that the user is new, thus cannot be root */
+		return FALSE;
+	} else {
+		/* node isn't set to userdb node, this means that the user is being modified */
+		group = gst_xml_get_child_content (node, "name");
+	
+		if (strcmp (group, "root") == 0)
+			return TRUE;
+	}
+	return FALSE;
+}
+
 static gboolean
 is_group_gid_valid (xmlNodePtr group_node, const gchar* gid)
 {
-	gchar *buf = NULL;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
 
-	if (!is_valid_id (gid))
-		buf = g_strdup (_("User id must be a positive number."));
+	if (!is_valid_id (gid)) {
+		primary_text   = g_strdup (_("Invalid group ID"));
+		secondary_text = g_strdup (_("Group ID must be a positive number."));
+	} else if (is_group_root (group_node) && (strcmp (gid, "0") != 0)) {
+		/* if group is root */
+		primary_text   = g_strdup (_("root group ID should not be modified"));
+		secondary_text = g_strdup (_("This would leave the system unusable"));
+	} else if (node_exists (group_node, "gid", gid)) {
+		/* Check if gid is available */
+		primary_text   = g_strdup (_("Invalid group ID"));
+		secondary_text = g_strdup_printf (_("Group ID %s already exists."), gid);
+	}
 	
-	/* Check if gid is available */
-	else if (node_exists (group_node, "gid", gid))
-		buf = g_strdup (_("Such group id already exists."));
-	
-	if (buf) {
-		show_error_message ("group_settings_dialog", buf);
-		g_free (buf);
+	if (primary_text) {
+		show_error_message ("group_settings_dialog", primary_text, secondary_text);
+		g_free (primary_text);
+		g_free (secondary_text);
 		
 		return FALSE;
 	}
@@ -181,31 +186,39 @@ is_group_gid_valid (xmlNodePtr group_node, const gchar* gid)
 static gboolean
 is_group_name_valid (xmlNodePtr node, const gchar *name)
 {
-	gchar *buf = NULL;
-
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
+	
 	g_return_val_if_fail (node != NULL, FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
 
-	/* If !empty. */
-	if (strlen (name) < 1)
-		buf = g_strdup (_("Group name is empty."));
-
-	/* If too long. */
-	if (strlen (name) > 16)
-		buf = g_strdup (_("The group name is too long."));
-
-	/* if invalid. */
-	else if (!is_valid_name (name))
-		buf = g_strdup (_("Please set a valid group name, using only lower-case letters."));
-
-	/* if !exist. */
-	else if (node_exists (node, "name", name))
-		buf = g_strdup (_("Group already exists."));
+	if (strlen (name) < 1) {
+		/* If empty. */
+		primary_text   = g_strdup (_("Group name is empty."));
+		secondary_text = g_strdup (_("A group name must be specified"));
+	} else if (strlen (name) > 16) {
+		/* If too long. */
+		primary_text   = g_strdup (_("The group name is too long."));
+		secondary_text = g_strdup_printf (_("The group name should have less than %i characters for being valid"), 16);
+	} else if (!is_valid_name (name)) {
+		/* if invalid. */
+		primary_text   = g_strdup (_("Group name has invalid characters"));
+		secondary_text = g_strdup (_("Please set a valid group name, using only lower case letters."));
+	} else if (node_exists (node, "name", name)) {
+		/* if !exist. */
+		primary_text   = g_strdup_printf (_("Group \"%s\" already exists."), name);
+		secondary_text = g_strdup (_("Please select a different group name"));
+	} else if (is_group_root (node) && (strcmp (name, "root") != 0)) {
+		/* if it's the root group */
+		primary_text   = g_strdup (_("Root group name should not be modified"));
+		secondary_text = g_strdup (_("This would leave the system unusable"));
+	}
 
 	/* If anything is wrong. */
-	if (buf) {
-		show_error_message ("group_settings_dialog", buf);
-		g_free (buf);
+	if (primary_text) {
+		show_error_message ("group_settings_dialog", primary_text, secondary_text);
+		g_free (primary_text);
+		g_free (secondary_text);
 
 		return FALSE;
 	} else {
@@ -229,9 +242,9 @@ group_update (ug_data *gd)
 	if (!is_group_gid_valid (gd->node, gid)) {
 		return FALSE;
 	}
-	
-	users = g_list_copy (g_object_get_data (G_OBJECT (group_settings_members), "list"));
-	
+
+	users = get_gtk_tree_list_items (GTK_TREE_VIEW (group_settings_members));
+
 	if (gd->is_new) {
 		/* Add new group, update table. */
 		xmlNodePtr node;
@@ -251,7 +264,7 @@ group_update (ug_data *gd)
 static gboolean
 check_group_delete (xmlNodePtr node)
 {
-	gchar *name, *txt;
+	gchar *name, *primary_text, *secondary_text;
 	GtkWindow *parent;
 	GtkWidget *dialog;
 	gint reply;
@@ -261,32 +274,41 @@ check_group_delete (xmlNodePtr node)
 	parent = GTK_WINDOW (tool->main_dialog);
 	name = gst_xml_get_child_content (node, "name");
 
-	if (!name)
-	{
+	if (!name) {
 		g_warning ("check_group_delete: Can't get group's name");
 		return FALSE;
 	}
 
-	if (strcmp (name, "root") == 0)
-	{
-		txt = g_strdup (_("The root group must not be deleted."));
-		show_error_message ("group_settings_dialog", txt);
+	if (strcmp (name, "root") == 0) {
+		primary_text   = g_strdup (_("Root group shouldn't be deleted."));
+	        secondary_text = g_strdup (_("This would leave the system unusable"));
+		show_error_message ("group_settings_dialog", primary_text, secondary_text);
+
 		g_free (name);
-		g_free (txt);
+		g_free (primary_text);
+		g_free (secondary_text);
+
 		return FALSE;
 	}
 
-	txt = g_strdup_printf (_("Are you sure you want to delete group %s?"), name);
-	dialog = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, txt);
+	dialog = gst_hig_dialog_new (parent,
+				     GTK_DIALOG_MODAL,
+				     GST_HIG_MESSAGE_WARNING,
+				     NULL,
+				     _("This may leave files with invalid group ID in the filesystem"),
+				     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				     GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
+				     NULL);
+	gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (dialog),
+					 _("Are you sure you want to delete group %s?"), name);
 	reply = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
-	g_free (txt);
 	g_free (name);
 	
-	if (reply == GTK_RESPONSE_NO)
-		return FALSE;
-        else
+	if (reply == GTK_RESPONSE_ACCEPT)
 		return TRUE;
+        else
+		return FALSE;
 }
 
 gboolean 
@@ -312,14 +334,12 @@ group_settings_dialog_prepare (ug_data *gd)
 
 	g_return_if_fail (gd != NULL);
 	
-	/* Fill group members */
 	create_users_gtk_trees ();
-	create_users_lists (gd->node, &group_settings_all_list, &group_settings_members_list);
+	group_settings_members_list = get_group_users (gd->node);
+	group_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("login", NODE_USER),
+							       group_settings_members_list);
 	populate_gtk_tree_list (GTK_TREE_VIEW (group_settings_members), group_settings_members_list);
-	
-	/* Attach the GLists to the GtkTreeViews */
-	g_object_set_data (G_OBJECT (group_settings_all), "list", group_settings_all_list);
-	g_object_set_data (G_OBJECT (group_settings_members), "list", group_settings_members_list);
+	populate_gtk_tree_list (GTK_TREE_VIEW (group_settings_all), group_settings_all_list);
 
 	/* Set group name */
 	name = gst_xml_get_child_content (gd->node, "name");
@@ -333,11 +353,7 @@ group_settings_dialog_prepare (ug_data *gd)
 	gtk_widget_set_sensitive (w0, gst_tool_get_access (tool));
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 
-	/* Fill all users list */
-	populate_gtk_tree_list (GTK_TREE_VIEW (group_settings_all), group_settings_all_list);
-
 	/* Show group settings dialog */
-
 	w0 = gst_dialog_get_widget (tool->main_dialog, "group_settings_dialog");
 	txt = g_strdup_printf (_("Settings for Group %s"), name);
 	gtk_window_set_title (GTK_WINDOW (w0), txt);
