@@ -141,6 +141,8 @@ populate_groups_table (void)
 	
 	g_return_if_fail (model != NULL);
 	g_return_if_fail (root != NULL);
+
+	gtk_tree_store_clear (GTK_TREE_STORE (model));
 	
 	for (group = gst_xml_element_find_first (root, "group"); group != NULL; group = gst_xml_element_find_next (group, "group"))
 	{
@@ -173,21 +175,27 @@ groups_table_set_cursor (gchar *old_group)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gchar *group;
+	gboolean valid;
 	
 	if (old_group == NULL)
-		return;	
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (groups_table));
-	if (gtk_tree_model_get_iter_first (model, &iter) != TRUE)
 		return;
-	do {
+	
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (groups_table));
+	valid = gtk_tree_model_get_iter_first (model, &iter);
+
+	while (valid) {
 		gtk_tree_model_get (model, &iter, 0, &group, -1);
-		if (strcmp (old_group, group) == 0 ) 
-		{
+
+		if (strcmp (old_group, group) == 0 ) {
 			GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
 			gtk_tree_view_set_cursor (GTK_TREE_VIEW (groups_table), path, NULL, FALSE);
 			gtk_tree_path_free (path);
+
+			return;
 		}
-	} while (gtk_tree_model_iter_next (model, &iter) != FALSE);
+
+		valid = gtk_tree_model_iter_next (model, &iter);
+	}
 }
 
 void
